<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Mail\NewAccountsPassword;
use App\Models\Admin;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;

class AdminsController extends Controller
{

    public function __construct()
    {
        $this->middleware(['permission:admin,admin']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
//        $role = Role::all();
//        return $role;
        $rows = Admin::whereType('admin')->orderByDesc('id')->paginate(10);
        $active_rows = Admin::whereType('admin')->where('status', 'active')->orderByDesc('id')->paginate(10);
        $not_active_rows = Admin::whereType('admin')->where('status', 'not_active')->orderByDesc('id')->paginate(10);
        return view('admin.admin.index', compact('rows', 'active_rows', 'not_active_rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.admin.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:admins,email',
            'mobile' => 'required|unique:admins,mobile',
            'password' => 'required|min:6',
        ]);

        $admin = new Admin();
        $admin['name'] = $request['name'];
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        $admin['status'] = $request['status'];
        $admin['password'] = bcrypt($request['password']);
        $admin->save();


        $role = Role::create(['guard_name' => 'admin', 'name' => $admin->email]);

        $permissions = $request['permissions'];
        foreach ($permissions as $permission) {
            $role->givePermissionTo($permission);
        }
        $admin->assignRole($role->name);

        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('admins.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Admin::find($id);
        return view('admin.admin.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:admins,email,' . $id,
            'mobile' => 'required|unique:admins,mobile,' . $id,
            'password' => 'nullable|min:6'
        ]);
        $admin = Admin::find($id);
        $admin['name'] = $request['name'];
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        $admin['status'] = $request['status'];
        if ($request['password']) $admin['password'] = bcrypt($request['password']);
        $admin->update();

        $role = Role::where('name', $admin->email)->first();
        $old_permissions = $admin->getAllPermissions();
        foreach ($old_permissions as $old_permission) {
            $role->revokePermissionTo($old_permission->name);
        }

        foreach ($request['permissions'] as $permission) {
            $role->givePermissionTo($permission);
        }

        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('admins.index');

    }


    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Admin::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->back();
    }

    public function admin_search(Request $request)
    {
        $this->validate($request, [
            'search' => 'required'
        ]);
        $req = $request->search;
        $search = is_numeric($request->search);
        if ($search == 1) {
            $rows = Admin::where('mobile', 'LIKE', "%$request->search%")->paginate(10);
        } else {
            $rows = Admin::where('name', 'LIKE', "%$request->search%")->paginate(10);
        }
        return view('admin.admin.search', compact('rows', 'req'));
    }
}
