<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Jobs\PaidTax;
use App\Models\Order;
use App\Repositories\Worker\SendMessagesRepository;
use Carbon\Carbon;
use Illuminate\Http\Request;

class AllOrdersController extends Controller
{


    public function __construct()
    {
        $this->middleware(['permission:all_orders,admin']);
    }

    public function index()
    {
        $rows = Order::orderByDesc('id')->paginate(10);
        $orders_paid = Order::where('status', 'delivered')->sum('profit');
        $tax_not_paid = Order::where(['status' => 'delivered', 'tax_paid' => 'false'])->sum('tax');
        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
            'worker_refuse' => 'رفض العمل',
        ];
        $sms_rows = [];
        return view('admin.orders.all_orders', compact('rows', 'status', 'sms_rows', 'tax_not_paid', 'orders_paid'));
    }

    public function adminConvertAll($status)
    {

        $orders = Order::whereIn('id', \request()->ids)->get();
        $order_not_travel = [];
        foreach ($orders as $order) {
            if ($status == 'delivered') {
                if ($order->travel) {
                    $order->travel->warranty = Carbon::now()->addMonths(3)->toDateString();
                    $order->travel->update();
                    Order::where('id', $order->id)->update(['status' => $status
                    ]);
                } else {
                    $order_not_travel[] = $order->code;
                }
            } elseif ($status == 'travel') {
                if (!$order->travel) {
                    $order_not_travel[] = $order->code;
                } else {
                    Order::where('id', $order->id)->update(['status' => $status
                    ]);
                }
            } elseif ($status == 'worker_refuse') {
                Order::where('id', $order->id)->update(['status' => 'cancel', 'cancel_type' => 'worker_refuse'
                ]);

            } else {
                Order::where('id', $order->id)->update(['status' => $status
                ]);
            }

        }

        $send = new SendMessagesRepository();
        $send->send_sms_order_admin();

        if (count($order_not_travel) > 0) {
            $codes = implode(" - ", $order_not_travel);
            alert('خطأ', "عفوا هذه الطلبات  $codes لا يوجد لها رحلة ولا يمكن تحولها", 'error');
        } else {
            success_toast();
        }

        return redirect()->back();
    }


    public function orders_filter_money(Request $request)
    {


        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];
        $sms_rows = [];


        $this->validate($request, [
            'date_from' => 'required',
            'date_to' => 'required|gte:date_from',
            'type' => 'required'
        ]);

        $orders = Order::whereBetween('created_at', [$request->date_from, $request->date_to]);

        if ($request->type == 'tax_paid') {

            $check = 'false';

            $orders->where(['tax_paid' => 'true', 'status' => 'delivered']);

            $orders_paid = Order::whereBetween('created_at', [$request->date_from, $request->date_to])->where(['status' => 'delivered', 'tax_paid' => 'true'])->sum('profit');
            $tax_not_paid = '0';
        } elseif ($request->type == 'not_tax_paid') {

            $check = 'true';

            $orders->where(['tax_paid' => 'false', 'status' => 'delivered']);

            $orders_paid = Order::whereBetween('created_at', [$request->date_from, $request->date_to])->where(['status' => 'delivered', 'tax_paid' => 'false'])->sum('profit');
            $tax_not_paid = Order::whereBetween('created_at', [$request->date_from, $request->date_to])->where(['status' => 'delivered', 'tax_paid' => 'false'])->sum('tax');
        } else {
            $check = 'false';
            $orders_paid = Order::whereBetween('created_at', [$request->date_from, $request->date_to])->where('status', 'delivered')->sum('profit');
            $tax_not_paid = Order::whereBetween('created_at', [$request->date_from, $request->date_to])->where(['status' => 'delivered', 'tax_paid' => 'false'])->sum('tax');

        }

        $rows = $orders->paginate(15);
        return view('admin.orders.all_orders', compact('rows', 'status', 'sms_rows', 'orders_paid', 'tax_not_paid', 'check'));
    }


    public function paid_tax(Request $request)
    {

        $this->validate($request, [
            'from' => 'required',
            'to' => 'required'
        ]);

        $orders = Order::whereBetween('created_at', [$request->from, $request->to])->where(['status' => 'delivered', 'tax_paid' => 'false'])->get();

        foreach ($orders as $order) {

            $emailJob = (new PaidTax($order->id))->delay(Carbon::now()->addSeconds(3));
            dispatch($emailJob);
        }

        toast('تم دفع الضرائب على المده المحدده', 'success');
        return redirect()->route('all_orders.index');
    }

}
