<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use App\Models\Order;
use App\Models\Setting;
use App\Models\User;
use App\Repositories\Admin\OrdersRepository;
use App\Repositories\Client\UsersRepository;
use App\Repositories\Worker\CountriesRepository;
use App\Repositories\Worker\GivenNameOrderRepository;
use App\Repositories\Worker\JobTitlesRepository;
use Illuminate\Http\Request;

class GivenNameOrdersController extends Controller
{
    //


    private $usersRepository;
    /**
     * @var JobTitlesRepository
     */
    private $jobTitlesRepository;
    /**
     * @var CountriesRepository
     */
    private $countriesRepository;
    /**
     * @var GivenNameOrderRepository
     */
    private $givenNameOrderRepository;
    /**
     * @var OrdersRepository
     */
    private $ordersRepository;

    public function __construct(UsersRepository $usersRepository, JobTitlesRepository $jobTitlesRepository, CountriesRepository $countriesRepository, GivenNameOrderRepository $givenNameOrderRepository, OrdersRepository $ordersRepository)
    {
        $this->usersRepository = $usersRepository;
        $this->jobTitlesRepository = $jobTitlesRepository;
        $this->countriesRepository = $countriesRepository;
        $this->givenNameOrderRepository = $givenNameOrderRepository;
        $this->ordersRepository = $ordersRepository;
    }

    public function second_name_order()
    {
        $job_titles = $this->jobTitlesRepository->index();
        $cities = City::all();
        return view('admin.orders.givenNameOrders.second_name_order', compact('job_titles', 'cities'));
    }

    public function second_name_order_submit(Request $request)
    {

        $this->validate($request, [
            'name' => 'required',
            'reference_number' => 'required',
            'mobile' => 'required|min:10|max:10',
            'another_mobile' => 'required|min:10|max:10',
            'name_family_member' => 'required',
            'mobile_family_member' => 'required|min:10|max:10',
            'address_family_member' => 'required',
            'address' => 'required',
            'passport_number' => 'required|min:10|max:10',
            'passport_start' => 'required',
            'visa_number' => 'required|min:10|max:10',
            'gender' => 'required|in:male,female',
            'passport_end' => 'required',
            'passport_attachment' => 'required|image',
            'job_title_id' => 'required|exists:job_titles,id',
            'city_id' => 'required|exists:cities,id',
        ]);


        if ($request->hasFile('passport_attachment')) {
            $filename = time() . '.' . $request->passport_attachment->getClientOriginalExtension();
            $request->passport_attachment->move(public_path('images/orders'), $filename);
            $request['passport_image'] = $filename;
        }
        session()->put('given_name_details', $request->except(['_token', 'passport_attachment']));
        return redirect()->route('admin_third_given_name');

    }

    public function third_given_name()
    {
        $countries = $this->countriesRepository->index();
        return view('admin.orders.givenNameOrders.third_name_order', compact('countries'));
    }

    public function getOfficesByCountry(Request $request)
    {
        $rows = $this->usersRepository->Offices($request['country_id']);
        $officesResult = view('site.saudi.givenNameOrders.offices', compact('rows'))->render();
        return response()->json(['value' => true, 'officesResult' => $officesResult]);
    }

    public function third_name_order_submit(Request $request)
    {
        $this->validate($request, [
            'office_id' => 'required|exists:users,id'
        ]);

        session()->put('selected_country_id', $request['country_id']);

        $order_details = session()->get('given_name_details');
        $order_details['office_id'] = $request['office_id'];
        session()->put('given_name_details', $order_details);
        return redirect()->route('admin_fourth_given_name_order');
    }

    public function fourth_given_name_order()
    {
        $order_details = session()->get('given_name_details');

        if (!isset($order_details['office_id'])){
            toast('لابد من ادخال المكتب الاجنبي','error');
            return redirect()->back();
        }


        $orderType = session()->get('orderType');
        $orderPrice = User::whereId($order_details['office_id'])->value($orderType . '_price');
        $officeWallet = User::whereId($order_details['office_id'])->value('wallet');
        $worker_name = $order_details['name'];
        $office_name = $this->usersRepository->office_name($order_details['office_id']);

        return view('admin.orders.givenNameOrders.fourth_name_order', compact('worker_name', 'office_name','orderPrice', 'officeWallet'));
    }

    public function fourth_given_name_submit(Request $request)
    {
        $this->validate($request, [
            'totalPrice' => 'required',
            'family_card' => 'required|image'
        ]);


        $order_details = session()->get('given_name_details');
//        if ($request->hasFile('passport_image')) {
//            $filename = 'passport_image' . time() . '.' . $request['passport_image']->getClientOriginalExtension();
//            $request['passport_image']->move(public_path('images/orders'), $filename);
//            $order_details['passport_image'] = $filename;
//        }


        if ($request->hasFile('family_card')) {
            $filename = 'family_card' . time() . '.' . $request['family_card']->getClientOriginalExtension();
            $request['family_card']->move(public_path('images/orders'), $filename);
            $order_details['family_card'] = $filename;
        }
        $order_details['totalPrice'] = $request['totalPrice'];



        $setting = Setting::first();

        // نجيب السعر الكلي ونطرح منه التاكس ونطرح منه المكتب الاجنبي ودا نحطه في profit


        $orderType = session()->get('orderType');
        $foreign_orderPrice = User::whereId($order_details['office_id'])->value($orderType . '_price');

        $orderTax = ($request['totalPrice'] * $setting->tax / 100);
        $order_details['tax'] = $orderTax;
        $order_details['profit'] = $request['totalPrice'] - $orderTax - $foreign_orderPrice;
        $order_details['foreign_money'] = $foreign_orderPrice;
        session()->put('given_name_details', $order_details);


        return redirect()->route('admin_fifth_given_name_order');

    }

    public function fifth_given_name_order()
    {
        return view('admin.orders.givenNameOrders.fifth_name_order');
    }

    public function fifth_given_name_submit(Request $request)
    {
        $this->validate($request, [
            'follow_type' => 'required|in:sms,email,both',
            'client_sign' => 'required|image'
        ]);


        return $this->ordersRepository->givenNamestore();

    }

    public function last_given_name_order($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('admin.orders.givenNameOrders.last_given_name_order', compact('order'));
    }
}
