<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Licenses;
use App\Repositories\Admin\LicencesRepository;
use Illuminate\Http\Request;

class LicencesController extends Controller
{
    /**
     * @var LicencesRepository
     */
    private $licencesRepository;

    public function __construct(LicencesRepository $licencesRepository)
    {
        $this->licencesRepository = $licencesRepository;
        $this->middleware(['permission:licences,admin']);

    }

    public function index()
    {
        $rows = $this->licencesRepository->index();
        return view('admin.licences.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.licences.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'code' => 'required',
            'start_licence' => 'required',
//            'start_renew_licence' => 'required',
            'end_licence' => 'required',
//            'end_renew_licence' => 'required',
            'image' => 'required|image'
        ]);
        return $this->licencesRepository->store($request);
    }

    public function edit($id)
    {
        $row = Licenses::findOrFail($id);
        return view('admin.licences.edit', compact('row'));

    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'code' => 'required',
            'name' => 'required',
            'start_licence' => 'required',
//            'start_renew_licence' => 'required',
            'end_licence' => 'required',
//            'end_renew_licence' => 'required',

        ]);
        return $this->licencesRepository->update($id,$request);
    }

    public function destroy($id)
    {
        return $this->licencesRepository->destroy($id);
    }
}
