<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Jobs\SendMessages;
use App\Repositories\Admin\OrdersRepository;
use App\Repositories\Worker\SendMessagesRepository;
use Carbon\Carbon;
use Illuminate\Http\Request;

class MessagesController extends Controller
{
    /**
     * @var SendMessagesRepository
     */
    private $messagesRepository;
    /**
     * @var OrdersRepository
     */
    private $ordersRepository;

    public function __construct(SendMessagesRepository $messagesRepository, OrdersRepository $ordersRepository)
    {
        $this->messagesRepository = $messagesRepository;
        $this->ordersRepository = $ordersRepository;
        $this->middleware(['permission:messages,admin']);
    }

    public function index()
    {
        $sections = [
            'new' => 'الطلبات الجديدة',
            'foreign_accept' => 'عقد ورقي',
            'polo' => 'البولو',
            'verified' => 'موثق',
            'in_shipping' => 'إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'cancel' => 'الملغية',
        ];

        $messages = $this->messagesRepository->allMessages();
        return view('admin.messages', compact('sections', 'messages'));
    }

    public function getOrdersSectionAjax()
    {


        $rows = $this->ordersRepository->orders(\request()->section);


        $html = view('admin.orders.ordersOptions', compact('rows'))->render();


        return response()->json(['value' => true, 'html' => $html]);
    }

    public function sendGroupMessage(Request $request)
    {
        $this->validate($request, [
            'ids' => 'required',
            'message' => 'required'
        ]);
        foreach ($request->ids as $order_id) {
            $job = (new SendMessages($order_id, $request['message']))->delay(Carbon::now()->addSeconds(10));
            dispatch($job);
        }

        success_toast();
        return redirect()->back();


    }
}
