<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\OfficeExpenses;
use Illuminate\Http\Request;

class OfficeExpensesController extends Controller
{

    public function __construct()
    {
        $this->middleware(['permission:officeExpenses,admin']);
    }

    public function index()
    {
        $rows = OfficeExpenses::orderByDesc('id')->paginate(20);
        return view('admin.officeExpenses.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.officeExpenses.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'price' => 'required'
        ]);
        OfficeExpenses::create($request->all());
        success_toast();
        return redirect()->route('officeExpenses.index');
    }

    public function edit($id)
    {
        $row = OfficeExpenses::findOrFail($id);
        return view('admin.officeExpenses.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'price' => 'required'
        ]);
        OfficeExpenses::whereId($id)->update($request->except('_method', '_token'));
        success_toast();
        return redirect()->route('officeExpenses.index');
    }

    public function destroy($id)
    {
        OfficeExpenses::destroy($id);
        success_toast();
        return redirect()->route('officeExpenses.index');
    }
}
