<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\OrderExpenses;
use Illuminate\Http\Request;

class OrderExpensesController extends Controller
{
    public function index(Request $request)
    {
        $order = Order::findOrFail($request->get('id'));
        $rows = $order->orderExpenses()->paginate(20);
        return view('admin.orderExpenses.index', compact('order', 'rows'));
    }

    public function create(Request $request)
    {
        $order = Order::findOrFail($request->get('id'));
        return view('admin.orderExpenses.create', compact('order'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'order_id' => 'required',
            'name' => 'required',
            'price' => 'required',
        ]);
        OrderExpenses::create($request->all());

        $order = Order::findOrFail($request['order_id']);
        $order->profit -= $request['price'];
        $order->update();
        success_toast();
        return redirect()->route('orderExpenses.index', 'id=' . $request['order_id']);
    }

    public function edit($id)
    {
        $row = OrderExpenses::findOrFail($id);
        return view('admin.orderExpenses.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'price' => 'required',
        ]);
        $row = OrderExpenses::findOrFail($id);
        $order = Order::findOrFail($row->order_id);
        $oldPrice = $row->price;
        if ($oldPrice != $request['price']) {
            $order->profit += $oldPrice;
            $order->profit -= $request['price'];
            $order->update();
        }
        OrderExpenses::whereId($id)->update($request->except('_token','_method'));
        success_toast();
        return redirect()->route('orderExpenses.index', 'id=' . $row->order_id);
    }

    public function destroy($id)
    {
        $row = OrderExpenses::findOrFail($id);
        $order = Order::findOrFail($row->order_id);
        $order->profit += $row->price;
        $order->update();
        OrderExpenses::destroy($id);
        success_toast();
        return back();

    }
}
