<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Alert;
use App\Models\City;
use App\Models\Country;
use App\Models\Cv;
use App\Models\Order;
use App\Models\Setting;
use App\Models\User;
use App\Repositories\Admin\NationalitiesRepository;
use App\Repositories\Admin\OrdersRepository;
use App\Repositories\Client\UsersRepository;
use App\Repositories\Worker\CvsRepository;
use App\Repositories\Worker\JobTitlesRepository;
use Illuminate\Http\Request;

class OrdersController extends Controller
{

    private $ordersRepository;
    /**
     * @var UsersRepository
     */
    private $usersRepository;
    /**
     * @var NationalitiesRepository
     */
    private $nationalitiesRepository;
    /**
     * @var JobTitlesRepository
     */
    private $jobTitlesRepository;
    /**
     * @var CvsRepository
     */
    private $cvsRepository;

    public function __construct(OrdersRepository $ordersRepository, UsersRepository $usersRepository, NationalitiesRepository $nationalitiesRepository, JobTitlesRepository $jobTitlesRepository, CvsRepository $cvsRepository)
    {
        $this->ordersRepository = $ordersRepository;
        $this->usersRepository = $usersRepository;
        $this->nationalitiesRepository = $nationalitiesRepository;
        $this->jobTitlesRepository = $jobTitlesRepository;
        $this->cvsRepository = $cvsRepository;
    }

    public function single_order($id)
    {
        $row = $this->ordersRepository->order($id);
        return view('admin.order_details', compact('row'));
    }

    public function new_order()
    {
        $cities = City::all();
        return view('admin.orders.asRequestedOrders.new_order', compact('cities'));
    }


    public function first_requested_order(Request $request)
    {

        $client = $this->usersRepository->checkUserExist();

        $cities = City::all();

        if ($client && $client->civil_registry != $request['civil_registry']) {
            $validation = 'required|unique:users,email|email';
            $mobile_validation = 'required|unique:users,mobile|min:10|max:10';
        } elseif ($client) {
            $validation = 'required|email';
            $mobile_validation = 'required|min:10|max:10';
        } else {
            $validation = 'required|email';
            $mobile_validation = 'required|min:10|max:10';

        }

        $this->validate($request, [
            'client_name' => 'required',
            'client_mobile' => $mobile_validation,
            'civil_registry' => 'required|min:10|max:10',
//            'id_number' => 'required',

            'area' => 'required',
            'family_count' => 'required',
            'social_status' => 'required',
            'client_email' => $validation,
            'client_name_english' => 'required',
            'client_birthday' => 'required',
            'city_id' => 'required|exists:cities,id',
            'file_number' => 'required'
        ]);

        $client = $this->usersRepository->createNewAccount($request);

        session()->put('client_mobile', $client->mobile);
        session()->put('client', $client);
        session()->put('orderType', $request['orderType']);

        if ($request['orderType'] == 'as_requested') {
            return redirect()->route('admin_second_requested_order');
        } else {
            return redirect()->route('admin_second_name_order');
        }
    }

    public function second_requested_order()
    {
        $nationalities = $this->nationalitiesRepository->index();
        $job_titles = $this->jobTitlesRepository->index();
        return view('admin.orders.asRequestedOrders.second_requested_order', compact('nationalities', 'job_titles'));
    }

    public function second_request_submit(Request $request)
    {
        $this->validate($request, [
            'nationality_id' => 'required|exists:nationalities,id',
            'job_title_id' => 'required|exists:job_titles,id',
            'gender' => 'required|in:male,female',
            'visa_number' => 'required|min:10|max:10',
            'visa_issue_date' => 'required',
            'date_selection' => 'required',
        ]);


        session()->put('order_details', $request->except('_token'));
        return redirect()->route('admin_third_requested_order');
    }

    public function third_requested_order()
    {
        $cvs = $this->cvsRepository->matchedCvs();
        return view('admin.orders.asRequestedOrders.third_requested_order', compact('cvs'));

    }

    public function third_request_submit(Request $request)
    {


        $this->validate($request, [
            'cv_id' => 'required|exists:cvs,id'
        ]);

        $order_details = session()->get('order_details');
        $order_details['cv_id'] = $request['cv_id'];
        session()->put('order_details', $order_details);


        return redirect()->route('admin_fourth_requested_order');

    }

    public function fourth_requested_order()
    {


        $order_details = session()->get('order_details');
        if (session()->get('order_details') && isset(session()->get('order_details')['cv_id'])) {
            $cv = $this->cvsRepository->show($order_details['cv_id']);

            $orderType = session()->get('orderType');
            $orderPrice = User::whereId($cv->office_id)->value($orderType . '_price');
            $officeWallet = User::whereId($cv->office_id)->value('wallet');




        } else {
            $cv = null;
            toast("طلب غير مكتمل", 'error');
            return redirect()->back();
        }


        return view('admin.orders.asRequestedOrders.fourth_requested_order', compact('cv', 'orderPrice', 'officeWallet'));
    }

    public function fourth_requested_submit(Request $request)
    {
        $this->validate($request, [
            'totalPrice' => 'required',
            'family_card' => 'required|image'
        ]);
        $order_details = session()->get('order_details');
//        if ($request->hasFile('passport_image')) {
//            $filename = 'passport_image' . time() . '.' . $request['passport_image']->getClientOriginalExtension();
//            $request['passport_image']->move(public_path('images/orders'), $filename);
//            $order_details['passport_image'] = $filename;
//        }


        if ($request->hasFile('family_card')) {
            $filename = 'family_card' . time() . '.' . $request['family_card']->getClientOriginalExtension();
            $request['family_card']->move(public_path('images/orders'), $filename);
            $order_details['family_card'] = $filename;
        }
        $order_details['totalPrice'] = $request['totalPrice'];

        $setting = Setting::first();

        // نجيب السعر الكلي ونطرح منه التاكس ونطرح منه المكتب الاجنبي ودا نحطه في profit
        $cv = $this->cvsRepository->show($order_details['cv_id']);

        $orderType = session()->get('orderType');
        $foreign_orderPrice = User::whereId($cv->office_id)->value($orderType . '_price');

        $orderTax = ($request['totalPrice'] * $setting->tax / 100);
        $order_details['tax'] = $orderTax;
        $order_details['profit'] = $request['totalPrice'] - $orderTax - $foreign_orderPrice;
        $order_details['foreign_money'] = $foreign_orderPrice;
        session()->put('order_details', $order_details);


        return redirect()->route('admin_fifth_requested_order');

    }

    public function fifth_requested_order()
    {

        if (session()->get('order_details') && isset(session()->get('order_details')['cv_id'])) {
            return view('admin.orders.asRequestedOrders.fifth_requested_order');

        } else {
            $cv = null;
            toast("طلب غير مكتمل", 'error');
            return redirect()->back();
        }


    }

    public function fifth_requested_submit(Request $request)
    {
        $this->validate($request, [
            'follow_type' => 'required|in:sms,email,both',
            'client_sign' => 'required|image'
        ]);

        return $this->ordersRepository->store();


    }

    public function last_requested_order($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('admin.orders.asRequestedOrders.last_requested_order', compact('order'));

    }

    public function searchOrderCode(Request $request)
    {
        return $this->ordersRepository->searchOrder($request);
    }

    public function edit_order_admin($id)
    {
        $row = $this->ordersRepository->show($id);
        $cities = City::all();
        $countries = Country::all();
        $job_titles = $this->jobTitlesRepository->index();
        $cvs = $this->cvsRepository->matchedCvsOrder($row);
        $offices = User::where(['type' => 'foreign', 'country_id' => $row->office->country->id])->get();
        $order_cv = $row->cv;

        $nationalities = $this->nationalitiesRepository->index();

        if ($row->type == 'given_name') {
            return view('admin.orders.edit_name_order', compact('row', 'cities', 'job_titles', 'offices', 'countries'));
        }

        return view('admin.orders.edit_requested_order', compact('order_cv', 'cvs', 'row', 'cities', 'job_titles', 'offices', 'countries', 'nationalities'));
    }

    public function givenNameUpdate(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'gender' => 'required',
            'mobile' => 'required|max:10|min:10',
            'another_mobile' => 'required',
            'name_family_member' => 'required',
            'mobile_family_member' => 'required',
            'address_family_member' => 'required',
            'city_id' => 'required|exists:cities,id',
            'job_title_id' => 'required',
            'address' => 'required',
            'visa_number' => 'required|max:10|min:10',
            'passport_start' => 'required',
            'passport_end' => 'required',
            'passport_number' => 'required',
            'passport_attachment' => 'nullable|image',
            'office_id' => 'required',
            'family_card' => 'nullable|image',
            'client_sign' => 'nullable|image',
            'follow_type' => 'nullable',

        ]);
        $this->ordersRepository->givenNameUpdate($request, $id);
        toast('تم التعديل بنجاح', 'success');
        return redirect()->route('edit_order_admin', $id);
    }


    public function select_cv(Request $request)
    {
        $order_cv = $this->cvsRepository->show($request->cv_id);
        $view = view('admin.orders.default_cv_render', compact('order_cv'))->render();
        return response()->json(['html' => $view]);
    }

    public function ajax_order_cvs(Request $request)
    {


        $all_cvs = Cv::orderByDesc('id');

        if ($request->nationality_id) {
            $all_cvs->where('nationality_id', $request->nationality_id);
        }
        if ($request->job_title_id) {
            $all_cvs->where('job_title_id', $request->job_title_id);
        }
        if ($request->gender) {
            $all_cvs->where('gender', $request->gender);
        }
        if ($request->cv_id && $request->cv_id != 0) {
            $all_cvs->where('id', '!=', $request->cv_id);
        }
        $cvs = $all_cvs->get();

        $view_cvs = view('admin.orders.cv_render', compact('cvs'))->render();
        return response()->json(['html_cvs' => $view_cvs]);
    }


    public function asRequestedUpdate(Request $request, $id)
    {
        $this->validate($request, [
            'visa_number' => 'required|max:10|min:10',
            'visa_issue_date' => 'required',
            'date_selection' => 'required',
            'nationality_id' => 'required|exists:nationalities,id',
            'gender' => 'required|in:male,female',
            'job_title_id' => 'required',
            'follow_type' => 'nullable',
            'cv_id' => 'required|exists:cvs,id',
//            'office_id' => 'required',
            'family_card' => 'nullable|image',
            'client_sign' => 'nullable|image',

        ]);
        $this->ordersRepository->asRequestedUpdate($request, $id);
        toast('تم التعديل بنجاح', 'success');
        return redirect()->route('edit_order_admin', $id);
    }


}
