<?php

namespace App\Http\Controllers\Clients;

use App\Http\Controllers\Controller;
use App\Repositories\Client\UsersRepository;
use Illuminate\Http\Request;

class UsersController extends Controller
{
    private $usersRepository;

    public function __construct(UsersRepository $usersRepository)
    {
        $this->usersRepository = $usersRepository;
    }

    public function login_form()
    {
        if (\Auth::check()) {
            return redirect()->route('client_home');
        }
        return view('site.client.login');
    }

    public function login()
    {
        $this->validate(request(), [
            'mobile' => 'required',
            'password' => 'required'
        ], [
            'mobile.required' => \Lang::get('data.pleaseEnterTheMobileNumber'),
            'password.required' => \Lang::get('data.pleaseEnterThePassword')
        ]);
        return $this->usersRepository->login();
    }

    public function new_first_password()
    {
        $this->validate(request(), [
            'password' => 'required|confirmed|min:6'
        ], [
            'password.required' => \Lang::get('data.pleaseEnterThePassword'),
            'password.confirmed' => \Lang::get('data.pleaseMakeSureThePasswordMatches'),
        ]);
        return $this->usersRepository->new_first_password();
    }


    public function new_first_password_form()
    {
        return view('site.client.new_first_password');
    }

    public function forget_password_form()
    {
        return view('site.client.forgot-password');
    }

    public function forget_password_check_mobile()
    {
        $this->validate(request(), [
            'mobile' => 'required|exists:users,mobile',
        ], [
            'mobile.required' => \Lang::get('data.pleaseEnterTheMobileNumber'),
        ]);
        return $this->usersRepository->forget_password_check_mobile();
    }

    public function mobile_confirm()
    {
        $this->validate(request(), [
            'verification_code' => 'required',
        ], [
            'verification_code.required' => \Lang::get('data.codeRequired'),
        ]);
        return $this->usersRepository->mobile_confirm();
    }

    public function change_password()
    {
        $this->validate(request(), [
            'password' => 'required|confirmed|min:6'
        ], [
            'password.required' => \Lang::get('data.pleaseEnterThePassword'),
            'password.confirmed' => \Lang::get('data.pleaseMakeSureThePasswordMatches'),
        ]);
        return $this->usersRepository->change_password();
    }

    public function my_profile()
    {
        return view('site.client.profile');
    }

    public function update_profile()
    {
        $id = \Auth::user()->id;
        $this->validate(request(), [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile,' . $id
        ]);
        return $this->usersRepository->update_profile();
    }


    public function logout()
    {
        \Auth::logout();
        toast(\Lang::get('data.signedOut'), 'success');
        return redirect()->route('client_home');
    }
}
