<?php

namespace App\Http\Controllers\Foreign;

use App\Http\Controllers\Controller;
use App\Mail\OrderUpdates;
use App\Models\Order;
use App\Models\OrderTravel;
use App\Models\OrderUpdateRequests;
use App\Models\Setting;
use App\Models\Transfer;
use App\Models\User;
use App\Repositories\Foreign\ComplaintsRepository;
use App\Repositories\Foreign\OrdersRepository;
use Illuminate\Http\Request;

class OrdersController extends Controller
{

    private $ordersRepository;
    private $complaintsRepository;

    public function __construct(OrdersRepository $ordersRepository, ComplaintsRepository $complaintsRepository)
    {
        $this->ordersRepository = $ordersRepository;
        $this->complaintsRepository = $complaintsRepository;
    }


    public function orders()
    {
        $rows = $this->ordersRepository->orders();
        $sms_rows = [];
        return view('site.foreign.orders', compact('rows', 'sms_rows'));
    }

    public function order_ajax(Request $request)
    {
        $rows = $this->ordersRepository->orders($request->status);
        $view = view('site.foreign.order_ajax', compact('rows'))->render();
        return response()->json(['html' => $view]);

    }

    public function orders_foreign_ajax()
    {
        return $this->ordersRepository->orders_foreign_ajax();
    }

    public function orders_change_in_progress()
    {
        return $this->ordersRepository->change_orders_status('in_progress');
    }

    public function orders_change_travel()
    {
        return $this->ordersRepository->change_orders_status('travel');
    }

    public function order_search_ajax()
    {
        return $this->ordersRepository->order_search();
    }

    public function send_complaint_foreign()
    {
        $this->validate(request(), [
            'complaint' => 'required'
        ], [
            'complaint.required' => \Lang::get('data.pleaseEnterTheMessage'),
        ]);
        return $this->complaintsRepository->store_array();
    }

    public function single_order($id)
    {
        $row = $this->ordersRepository->order($id);
        $updates = OrderUpdateRequests::where(['office_id' => \Auth::id()])->get();
        return view('site.foreign.single_order', compact('row', 'updates'));
    }

    public function add_processes($order_id)
    {
        $order = $this->ordersRepository->order($order_id);
        $processes = ['NBI', 'MEDICAL', 'PEOS', 'TESDA', 'OWWA', 'OEC', 'BIOMETRIC', 'STAMPING', 'PT', 'FLIGHT'];
        return view('site.foreign.add_processes', compact('order', 'processes'));
    }

    public function add_processes_form()
    {
        $this->validate(request(), [
            'process' => 'required',
            'start_date' => 'required',
            'end_date' => 'required|after:start_date',
            'image' => 'required'
        ]);
        $this->ordersRepository->add_processes();
        success_toast();
        return redirect()->route('single_order_foreign', request()->order_id);

    }

    public function change_travel($order_id)
    {
        $order_travel = $this->ordersRepository->order_travel($order_id);
        return view('site.foreign.change_travel', compact('order_travel', 'order_id'));
    }

    public function change_travel_form($id = null)
    {
        $this->validate(request(), [
            'number_flight' => 'required',
            'date_flight' => 'required',
            'date_arrive_flight' => 'required|after:start_date',
            'destination' => 'required',
            'came_from' => 'required',
            'flight_company' => 'required',
            'flight_time' => 'required'
        ]);
        $this->ordersRepository->change_travel($id ? $id : '');
        success_toast();
        return redirect()->route('single_order_foreign', request()->order_id);
    }

    public function refuse_order($id)
    {
        $this->validate(request(), [
            'reason' => 'required'
        ]);


        $this->ordersRepository->refuse_order($id);
        success_toast();
        return redirect()->back();
    }

    public function cancel_order($id)
    {
        $this->validate(request(), [
            'reason' => 'required_if:cancel_select,null'
        ]);


        if (\Auth::user()->trusted_office == 'true') {


            $this->ordersRepository->cancel_order($id);
            $order = Order::findOrFail($id);

            $setting = Setting::first();
            \Mail::to([$setting ? $setting->email : '', $order->client->email])->send(new OrderUpdates($order));
            if ($order->transfer_money_status) {
                $office = User::find(\Auth::user()->id);
                $office->wallet += \Auth::user()->foreign_money;
                $office->update();
                alert('CANCELLING ORDER', 'The order has been canceled and the amount paid will be deducted from the next order', 'success');
            } else {
                success_toast();
            }
            return view('site.foreign.cancelLetter', compact('order'));
        } else {
            $this->ordersRepository->trusted_office_cancel($id);

            toast('success', 'تم إرسال طلب إلغاء للإدارة وسوف يقوم بالرد عليكم');

            return redirect()->back();
        }

    }

    public function accept_order($id)
    {
        $this->ordersRepository->accept_order($id);
        success_toast();
        return redirect()->back();
    }

    public function index_order_travels()
    {
        return $this->ordersRepository->index_order_travels();
    }

    public function search_travels()
    {
        $search_travels = $this->ordersRepository->search_travels();
        return view('site.foreign.flights', compact('search_travels'));
    }

    public function get_reply_update_order()
    {
        $rows = OrderUpdateRequests::where('office_id', \Auth::id())->paginate(10);
        return view('site.foreign.update_orders_request', compact('rows'));
    }

    public function reply_update_order(Request $request, $id)
    {
        $this->validate(request(), [
            'message' => 'required'
        ]);
        $update_order = OrderUpdateRequests::find($id);
        if ($update_order->status == 'admin_translated') {
            toast('تم الرد عليه من قبل', 'error');
            return redirect()->back();
        }

        $update_order['message->en'] = $request->message;
        $update_order->status = 'foreign_replay';
        $update_order->update();

        toast('تم ارسال الرد بنجاح', 'success');
        return redirect()->back();
    }

    public function cancelLetter($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('site.foreign.cancelLetter', compact('order'));
    }

    public function foreign_transfers()
    {
        $rows = Transfer::where('office_id', \Auth::user()->id)->paginate(15);
        return view('site.foreign.foreign_transfers', compact('rows'));
    }

    public function done_transfer($id)
    {
        $row = Transfer::find($id);
        $row->foreign_accept = 'true';
        $row->update();
        success_toast();
        return redirect()->back();
    }
}
