<?php

namespace App\Http\Controllers\Foreign;

use App\Http\Controllers\Controller;
use App\Repositories\Foreign\ResumesRepository;
use App\Repositories\Foreign\SkillsRepository;
use App\Repositories\Worker\JobTitlesRepository;
use App\Repositories\Worker\NationalitiesRepository;
use Illuminate\Http\Request;

class ResumesController extends Controller
{

    private $resumesRepository;
    /**
     * @var JobTitlesRepository
     */
    private $jobTitlesRepository;
    /**
     * @var NationalitiesRepository
     */
    private $nationalitiesRepository;
    /**
     * @var SkillsRepository
     */
    private $skillsRepository;

    public function __construct(ResumesRepository $resumesRepository, JobTitlesRepository $jobTitlesRepository, NationalitiesRepository $nationalitiesRepository, SkillsRepository $skillsRepository)
    {
        $this->resumesRepository = $resumesRepository;
        $this->jobTitlesRepository = $jobTitlesRepository;
        $this->nationalitiesRepository = $nationalitiesRepository;
        $this->skillsRepository = $skillsRepository;
    }

    public function index()
    {
        $rows = $this->resumesRepository->index();
        $jobs = $this->jobTitlesRepository->index();
        $nationalities = $this->nationalitiesRepository->index();

        return view('site.foreign.resumes.index', compact('rows', 'jobs', 'nationalities'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [


            'name' => 'required',
            'passport_number' => 'required',
            'religion' => 'required',
            'age' => 'required',
            'address' => 'required',
            'mobile' => 'required',
            'social_status' => 'required',
            'job_title_id' => 'required',
            'nationality_id' => 'required',
            'gender' => 'required',
            'reference_number' => 'required',
            'salary' => 'required',
            'birthday' => 'required',

            'weight' => 'required',
            'height' => 'required',
            'education_qualification' => 'required',
            'issue_date' => 'required',
            'expire_date' => 'required',
            'issue_place' => 'required',
            'mobile_family_member' => 'required',
            'arabic_lang' => 'required',
            'english_lang' => 'required',
            'name_family_member' => 'required',
            'image' => 'required|image',
            'full_image' => 'required|image',
            'passport_image' => 'required|image',]);


        return $this->resumesRepository->store($request);

    }

    public function show($id)
    {
        $row = $this->resumesRepository->show($id);
        return view('site.foreign.resumes.show', compact('row'));
    }

    public function destroy($id)
    {
        return $this->resumesRepository->destroy($id);
    }

    public function create()
    {
        $jobs = $this->jobTitlesRepository->index();
        $nationalities = $this->nationalitiesRepository->index();
        $skills = $this->skillsRepository->index();
        return view('site.foreign.resumes.create', compact('jobs', 'nationalities', 'skills'));
    }

    public function edit($id)
    {
        $row = $this->resumesRepository->show($id);
        $jobs = $this->jobTitlesRepository->index();
        $nationalities = $this->nationalitiesRepository->index();
        $skills = $this->skillsRepository->index();
        return view('site.foreign.resumes.edit', compact('jobs', 'nationalities', 'skills', 'row'));

    }

    public function update($id, Request $request)
    {
        $this->validate($request, [


            'name' => 'required',
            'passport_number' => 'required',
            'religion' => 'required',
            'age' => 'required',
            'address' => 'required',
            'mobile' => 'required',
            'social_status' => 'required',
            'job_title_id' => 'required',
            'nationality_id' => 'required',
            'gender' => 'required',
            'reference_number' => 'required',
            'salary' => 'required',
            'birthday' => 'required',
            'weight' => 'required',
            'height' => 'required',
            'education_qualification' => 'required',
            'issue_date' => 'required',
            'expire_date' => 'required',
            'issue_place' => 'required',
            'mobile_family_member' => 'required',
            'arabic_lang' => 'required',
            'english_lang' => 'required',
            'name_family_member' => 'required',
            'image' => 'image',
            'full_image' => 'image',
            'passport_image' => 'image',
            ]);
        return $this->resumesRepository->update($id,$request);

    }
}
