<?php

namespace App\Http\Controllers\Workers;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\User;
use App\Repositories\Client\UsersRepository;
use App\Repositories\Worker\CvsRepository;
use App\Repositories\Worker\JobTitlesRepository;
use App\Repositories\Worker\NationalitiesRepository;
use App\Repositories\Worker\OrdersRepository;
use App\Repositories\Worker\SendMessagesRepository;
use Illuminate\Http\Request;

class OrdersController extends Controller
{
    private $ordersRepository;
    private $messagesRepository;
    private $usersRepository;
    private $nationalitiesRepository;
    private $jobTitlesRepository;
    private $cvsRepository;

    public function __construct(OrdersRepository $ordersRepository, SendMessagesRepository $messagesRepository, UsersRepository $usersRepository, NationalitiesRepository $nationalitiesRepository, JobTitlesRepository $jobTitlesRepository, CvsRepository $cvsRepository)
    {
        $this->ordersRepository = $ordersRepository;
        $this->messagesRepository = $messagesRepository;
        $this->usersRepository = $usersRepository;
        $this->nationalitiesRepository = $nationalitiesRepository;
        $this->jobTitlesRepository = $jobTitlesRepository;
        $this->cvsRepository = $cvsRepository;
    }

    public function orders()
    {
        $rows = $this->ordersRepository->orders();
        $sms_rows = [];
        return view('site.saudi.orders', compact('rows', 'sms_rows'));
    }

    public function order_ajax(Request $request)
    {
        $rows = $this->ordersRepository->orders($request->status);
        $view = view('site.saudi.order_ajax', compact('rows'))->render();
        return response()->json(['html' => $view]);

    }

    public function orders_clients_ajax()
    {
        return $this->ordersRepository->orders_clients_ajax();
    }

    public function send_sms_clients()
    {
        $this->validate(request(), [
            'message' => 'required'
        ], [
            'message.required' => \Lang::get('data.pleaseEnterTheMessage'),
        ]);
        return $this->messagesRepository->send_sms_order();
    }


    public function orders_change_in_shipping()
    {
        return $this->ordersRepository->change_orders_status('in_shipping');
    }

    public function orders_change_delivered()
    {
        return $this->ordersRepository->change_orders_status('delivered');
    }

    public function orders_change_in_worker_refuse()
    {
        return $this->ordersRepository->change_orders_status('cancel');
    }

    public function orders_change_verified()
    {
        return $this->ordersRepository->change_orders_status('verified');
    }

    public function order_search_ajax()
    {
        return $this->ordersRepository->order_search();
    }

    public function worker_order($id)
    {
        $row = $this->ordersRepository->order($id);
        return view('site.saudi.single_order', compact('row'));
    }


    public function requested_order()
    {

        return view('site.saudi.orders.requested_order');
    }


    public function first_requested_order(Request $request)
    {

        $client = $this->usersRepository->checkUserExist();

        if ($client && $client->mobile != $request['client_mobile']) {
            $validation = 'required|unique:users,email|email';
        } elseif ($client) {
            $validation = 'required|email';
        } else {
            $validation = 'required|email';

        }

        $this->validate($request, [
            'client_name' => 'required',
            'client_mobile' => 'required',
            'civil_registry' => 'required',
            'id_number' => 'required',
            'city' => 'required',
            'area' => 'required',
            'family_count' => 'required',
            'social_status' => 'required',
            'client_email' => $validation,
            'client_residency_number' => 'required',
        ]);

        $client = $this->usersRepository->createNewAccount();

        session()->put('client_mobile', $client->mobile);
        session()->put('client', $client);
        return redirect()->route('second_requested_order');
    }

    public function second_requested_order()
    {
        $nationalities = $this->nationalitiesRepository->index();
        $job_titles = $this->jobTitlesRepository->index();
        return view('site.saudi.orders.second_requested_order', compact('nationalities', 'job_titles'));
    }

    public function second_request_submit(Request $request)
    {
        $this->validate($request, [
            'visa_number' => 'required',
            'nationality_id' => 'required|exists:nationalities,id',
            'job_title_id' => 'required|exists:job_titles,id',
            'gender' => 'required|in:male,female'
        ]);

        session()->put('order_details', $request->except('_token'));
        return redirect()->route('third_requested_order');
    }

    public function third_requested_order()
    {
        $cvs = $this->cvsRepository->matchedCvs();
        return view('site.saudi.orders.third_requested_order', compact('cvs'));

    }

    public function third_request_submit(Request $request)
    {


        $this->validate($request, [
            'cv_id' => 'required|exists:cvs,id'
        ]);

        $order_details = session()->get('order_details');
        $order_details['cv_id'] = $request['cv_id'];
        session()->put('order_details', $order_details);

        return redirect()->route('fourth_requested_order');

    }

    public function fourth_requested_order()
    {

        $order_details = session()->get('order_details');
        $cv = $this->cvsRepository->show($order_details['cv_id']);
        return view('site.saudi.orders.fourth_requested_order', compact('cv'));
    }

    public function fourth_requested_submit(Request $request)
    {
        $this->validate($request, [
            'passport_image' => 'required|image',
            'family_card' => 'required|image'
        ]);
        $order_details = session()->get('order_details');
        if ($request->hasFile('passport_image')) {
            $filename = 'passport_image' . time() . '.' . $request['passport_image']->getClientOriginalExtension();
            $request['passport_image']->move(public_path('images/orders'), $filename);
            $order_details['passport_image'] = $filename;
        }


        if ($request->hasFile('family_card')) {
            $filename = 'family_card' . time() . '.' . $request['family_card']->getClientOriginalExtension();
            $request['family_card']->move(public_path('images/orders'), $filename);
            $order_details['family_card'] = $filename;
        }
        session()->put('order_details', $order_details);

        return redirect()->route('fifth_requested_order');

    }

    public function fifth_requested_order()
    {
        return view('site.saudi.orders.fifth_requested_order');
    }

    public function fifth_requested_submit(Request $request)
    {
        $this->validate($request, [
            'follow_type' => 'required|in:sms,email,both',
            'client_sign' => 'required|image'
        ]);

        return $this->ordersRepository->store();


    }

    public function last_requested_order($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('site.saudi.orders.last_requested_order', compact('order'));

    }

}
