<?php

namespace App\Http\Controllers;


use App\Http\Controllers\Workers\AlertsController;
use App\Http\Controllers\Workers\ComplaintsController;
use App\Http\Controllers\Workers\GivenNameOrdersController;
use App\Http\Controllers\Workers\HomeController;
use App\Http\Controllers\Workers\OrdersController;
use App\Http\Controllers\Workers\UsersController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Request;


$locale = Request::segment(1);

if ($locale == Config::get('app.available_locales')) {
    \App::setLocale($locale);
} else {
    $locale = null;
}


Route::get('/language/{lang}', [HomeController::class, 'change_language_web'])->name('language')->middleware('lang');
Route::get('compliant_search_ajax', [ComplaintsController::class, 'compliant_search_ajax'])->name('compliant_search_ajax');
Route::get('getOfficesByCountry', [GivenNameOrdersController::class, 'getOfficesByCountry'])->name('getOfficesByCountry');

Route::get('alert_search_ajax', [AlertsController::class, 'alert_search_ajax'])->name('alert_search_ajax');

Route::group(['prefix' => $locale . '/worker', 'middleware' => 'lang'], function () {

    Route::get('/', [HomeController::class, 'index'])->name('worker_home');

    Route::get('login_form', [UsersController::class, 'login_form'])->name('login_form_worker');
    Route::post('login', [UsersController::class, 'login'])->name('login_worker');
    Route::get('forget_password_form', [UsersController::class, 'forget_password_form'])->name('forget_password_form_worker');
    Route::post('forget_password', [UsersController::class, 'forget_password_check_mobile'])->name('forget_password_worker');
    Route::post('mobile_confirm', [UsersController::class, 'mobile_confirm'])->name('mobile_confirm_worker');
    Route::post('change_password', [UsersController::class, 'change_password'])->name('change_password_worker');
    Route::get('forget_password', [UsersController::class, 'forget_password'])->name('forget_password_worker');


    Route::get('worker_complaints', [ComplaintsController::class, 'index'])->name('worker_complaints');
    Route::post('worker_new_complaint', [ComplaintsController::class, 'store'])->name('worker_new_complaint');
    Route::post('update_complaint/{complaint_id}', [ComplaintsController::class, 'update'])->name('update_complaint');
    Route::post('reply_complaint/{complaint_id}', [ComplaintsController::class , 'reply_complaint'])->name('reply_complaint');
    Route::get('about_us', [HomeController::class, 'about_us'])->name('about_us');


    Route::group(['middleware' => 'saudi'], function () {

        Route::get('logout', [UsersController::class, 'logout'])->name('logout_worker');
        Route::get('orders', [OrdersController::class, 'orders'])->name('orders_worker');
        Route::get('order_ajax', [OrdersController::class, 'order_ajax'])->name('order_ajax');
        Route::get('orders_clients_ajax', [OrdersController::class, 'orders_clients_ajax'])->name('orders_clients_ajax');
        Route::post('send_sms_clients', [OrdersController::class, 'send_sms_clients'])->name('send_sms_clients');
        Route::get('worker_complaints', [ComplaintsController::class, 'index'])->name('worker_complaints');
        Route::post('worker_new_complaint', [ComplaintsController::class, 'store'])->name('worker_new_complaint');
        Route::post('update_complaint/{complaint_id}', [ComplaintsController::class, 'update'])->name('update_complaint');
        Route::post('reply_complaint/{complaint_id}', [ComplaintsController::class, 'reply_complaint'])->name('reply_complaint');
        Route::get('worker_alerts', [AlertsController::class, 'index'])->name('worker_alerts');

        Route::post('orders_change_in_shipping', [OrdersController::class, 'orders_change_in_shipping'])->name('orders_change_in_shipping');
        Route::post('orders_change_verified', [OrdersController::class, 'orders_change_verified'])->name('orders_change_verified');
        Route::post('orders_change_in_worker_refuse', [OrdersController::class, 'orders_change_in_worker_refuse'])->name('orders_change_in_worker_refuse');
        Route::post('orders_change_delivered', [OrdersController::class, 'orders_change_delivered'])->name('orders_change_delivered');
        Route::get('order_search_ajax', [OrdersController::class, 'order_search_ajax'])->name('order_search_ajax');
        Route::get('worker_order/{id}', [OrdersController::class, 'worker_order'])->name('worker_order');

        // CREATE REQUESTED ORDERS
        Route::get('requested_order', [OrdersController::class, 'requested_order'])->name('requested_order');
        Route::post('first_requested_order', [OrdersController::class, 'first_requested_order'])->name('first_requested_order');
        Route::get('getClientInfo', [UsersController::class, 'getClientInfo'])->name('getClientInfo');
        Route::get('second_requested_order', [OrdersController::class, 'second_requested_order'])->name('second_requested_order');
        Route::post('second_request_submit', [OrdersController::class, 'second_request_submit'])->name('second_request_submit');
        Route::get('last_requested_order/{order_id}', [OrdersController::class, 'last_requested_order'])->name('last_requested_order');

        Route::group(['middleware' => 'checkOrderSession'], function () {

            Route::get('third_requested_order', [OrdersController::class, 'third_requested_order'])->name('third_requested_order');
            Route::post('third_request_submit', [OrdersController::class, 'third_request_submit'])->name('third_request_submit');
            Route::get('fourth_requested_order', [OrdersController::class, 'fourth_requested_order'])->name('fourth_requested_order');
            Route::post('fourth_requested_submit', [OrdersController::class, 'fourth_requested_submit'])->name('fourth_requested_submit');
            Route::get('fifth_requested_order', [OrdersController::class, 'fifth_requested_order'])->name('fifth_requested_order');
            Route::post('fifth_requested_submit', [OrdersController::class, 'fifth_requested_submit'])->name('fifth_requested_submit');
        });


        // CREATE GIVEN NAME ORDER

        Route::get('given_name_order', [GivenNameOrdersController::class, 'given_name_order'])->name('given_name_order');
        Route::post('first_name_order', [GivenNameOrdersController::class, 'first_name_order'])->name('first_name_order');
        Route::get('second_name_order', [GivenNameOrdersController::class, 'second_name_order'])->name('second_name_order');
        Route::post('second_name_order_submit', [GivenNameOrdersController::class, 'second_name_order_submit'])->name('second_name_order_submit');

        Route::get('last_given_name_order/{order_id}', [GivenNameOrdersController::class, 'last_given_name_order'])->name('last_given_name_order');
        Route::group(['middleware' => 'checkGivenNameSession'], function () {
            Route::get('third_given_name', [GivenNameOrdersController::class, 'third_given_name'])->name('third_given_name');
            Route::post('third_name_order_submit', [GivenNameOrdersController::class, 'third_name_order_submit'])->name('third_name_order_submit');
            Route::get('fourth_given_name_order', [GivenNameOrdersController::class, 'fourth_given_name_order'])->name('fourth_given_name_order');
            Route::post('fourth_given_name_submit', [GivenNameOrdersController::class, 'fourth_given_name_submit'])->name('fourth_given_name_submit');
            Route::get('fifth_given_name_order', [GivenNameOrdersController::class, 'fifth_given_name_order'])->name('fifth_given_name_order');
            Route::post('fifth_given_name_submit', [GivenNameOrdersController::class, 'fifth_given_name_submit'])->name('fifth_given_name_submit');
        });

    });


});
